=============================
inforcehub
=============================

.. image:: https://badge.fury.io/py/inforcehub.png
    :target: http://badge.fury.io/py/inforcehub

.. image:: https://travis-ci.org/Inforcehub/inforcehub.png?branch=master
    :target: https://travis-ci.org/Inforcehub/inforcehub

Utilities for data science and customer management


Features
--------

* **colors** module - to enable quick use of inforcehub branded colors


Installation
------------

To install the module in your virtual environment using pip::

    pip install inforcehub


Requirements
------------

Python 3.4 or later 


Documentation
-------------

Full documentation can be found at http://inforcehub.rtfd.org

